==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/KeyToPathBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KeyToPathBuilder extends KeyToPathFluentImpl<KeyToPathBuilder> implements VisitableBuilder<KeyToPath,KeyToPathBuilder>{
  public KeyToPathBuilder() {
    this(false);
  }
  public KeyToPathBuilder(Boolean validationEnabled) {
    this(new KeyToPath(), validationEnabled);
  }
  public KeyToPathBuilder(KeyToPathFluent<?> fluent) {
    this(fluent, false);
  }
  public KeyToPathBuilder(KeyToPathFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KeyToPath(), validationEnabled);
  }
  public KeyToPathBuilder(KeyToPathFluent<?> fluent,KeyToPath instance) {
    this(fluent, instance, false);
  }
  public KeyToPathBuilder(KeyToPathFluent<?> fluent,KeyToPath instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withKey(instance.getKey());
      fluent.withMode(instance.getMode());
      fluent.withPath(instance.getPath());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public KeyToPathBuilder(KeyToPath instance) {
    this(instance,false);
  }
  public KeyToPathBuilder(KeyToPath instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withKey(instance.getKey());
      this.withMode(instance.getMode());
      this.withPath(instance.getPath());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  KeyToPathFluent<?> fluent;
  Boolean validationEnabled;
  public KeyToPath build() {
    KeyToPath buildable = new KeyToPath(fluent.getKey(),fluent.getMode(),fluent.getPath());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/KeyToPathBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class KeyToPathBuilder extends KeyToPathFluent<KeyToPathBuilder> implements VisitableBuilder<KeyToPath,KeyToPathBuilder>{
  public KeyToPathBuilder() {
    this(false);
  }
  public KeyToPathBuilder(Boolean validationEnabled) {
    this(new KeyToPath(), validationEnabled);
  }
  public KeyToPathBuilder(KeyToPathFluent<?> fluent) {
    this(fluent, false);
  }
  public KeyToPathBuilder(KeyToPathFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new KeyToPath(), validationEnabled);
  }
  public KeyToPathBuilder(KeyToPathFluent<?> fluent,KeyToPath instance) {
    this(fluent, instance, false);
  }
  public KeyToPathBuilder(KeyToPathFluent<?> fluent,KeyToPath instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new KeyToPath());

    if (instance != null) {
      fluent.withKey(instance.getKey());
      fluent.withMode(instance.getMode());
      fluent.withPath(instance.getPath());
      fluent.withKey(instance.getKey());
      fluent.withMode(instance.getMode());
      fluent.withPath(instance.getPath());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public KeyToPathBuilder(KeyToPath instance) {
    this(instance,false);
  }
  public KeyToPathBuilder(KeyToPath instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new KeyToPath());

    if (instance != null) {
      this.withKey(instance.getKey());
      this.withMode(instance.getMode());
      this.withPath(instance.getPath());
      this.withKey(instance.getKey());
      this.withMode(instance.getMode());
      this.withPath(instance.getPath());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  KeyToPathFluent<?> fluent;
  Boolean validationEnabled;
  public KeyToPath build() {
    KeyToPath buildable = new KeyToPath(fluent.getKey(),fluent.getMode(),fluent.getPath());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
